# lndb-app: Web app to interact with Lamin instances

## Init

Install package

```
pip install .
```

then

```
lndb-app init
```

## Run

```
lndb-app run
```

## Stop

```
lndb-app stop
```

## Run in dev mode

Make sure [Node](https://nodejs.org/en/download/) and [Yarn](https://classic.yarnpkg.com/lang/en/docs/install/) are installed.

Install frontend dependencies

```
(cd lndb-ui && yarn install)
```

then

```
lndb-app run-dev
```
